@@ -44,9 +44,38 @@ utils::globalVariables(
     "Name_String",
     "Tiebreaker_String",
     "minimum_row",
-    "flights",
-    "flight_attempts",
+    "rounds",
+    "round_attempts",
     "split_attempts",
-    ":="
+    ":=",
+    "wide_format_vertical",
+    "wide_format_horizontal",
+    "wide_format_distance",
+    "wide_format",
+    "wide_format_clean",
+    "Time",
+    "id",
+    "Split_Distance",
+    "Split_Time",
+    "df",
+    "Gender",
+    "Round",
+    "Result",
+    "Wind",
+    "Standard",
+    "link",
+    "Location",
+    "Meet_Link",
+    "Date",
+    "Event_Date",
+    "Meet_Date",
+    "where",
+    "Input",
+    "Meet",
+    "Best",
+    "Height",
+    "relay_athletes",
+    "splits",
+    "split_length"
   )
 )
